# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/calendar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/calendar.proto\x12"pro.omni.oms.api.v1.rules.calendar\x1a\x11\x63ommon/base.proto"u\n\x08\x43\x61lendar\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12?\n\x0cobject_audit\x18\x04 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"]\n\x15\x43\x61lendarCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61lendarCreateResponse\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13\x43\x61lendarReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x14\x43\x61lendarReadResponse\x12?\n\tcalendars\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15\x43\x61lendarUpdateRequest\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61lendarUpdateResponse\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15\x43\x61lendarDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16\x43\x61lendarDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0f\x43\x61lendarService\x12\x89\x01\n\x0e\x43\x61lendarCreate\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarCreateRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarCreateResponse"\x00\x12\x83\x01\n\x0c\x43\x61lendarRead\x12\x37.pro.omni.oms.api.v1.rules.calendar.CalendarReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.calendar.CalendarReadResponse"\x00\x12\x89\x01\n\x0e\x43\x61lendarUpdate\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarUpdateResponse"\x00\x12\x89\x01\n\x0e\x43\x61lendarDelete\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.calendar_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _CALENDAR._serialized_start = 82
    _CALENDAR._serialized_end = 199
    _CALENDARCREATEREQUEST._serialized_start = 201
    _CALENDARCREATEREQUEST._serialized_end = 294
    _CALENDARCREATERESPONSE._serialized_start = 297
    _CALENDARCREATERESPONSE._serialized_end = 460
    _CALENDARREADREQUEST._serialized_start = 463
    _CALENDARREADREQUEST._serialized_end = 832
    _CALENDARREADRESPONSE._serialized_start = 835
    _CALENDARREADRESPONSE._serialized_end = 1056
    _CALENDARUPDATEREQUEST._serialized_start = 1059
    _CALENDARUPDATEREQUEST._serialized_end = 1202
    _CALENDARUPDATERESPONSE._serialized_start = 1205
    _CALENDARUPDATERESPONSE._serialized_end = 1368
    _CALENDARDELETEREQUEST._serialized_start = 1370
    _CALENDARDELETEREQUEST._serialized_end = 1461
    _CALENDARDELETERESPONSE._serialized_start = 1463
    _CALENDARDELETERESPONSE._serialized_end = 1562
    _CALENDARSERVICE._serialized_start = 1565
    _CALENDARSERVICE._serialized_end = 2136
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import warehouse_delivery_method_pb2 as v1_dot_rules_dot_warehouse__delivery__method__pb2


class WarehouseDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WarehouseDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.FromString,
        )
        self.WarehouseDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.FromString,
        )
        self.WarehouseDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.FromString,
        )
        self.WarehouseDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.FromString,
        )


class WarehouseDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WarehouseDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "WarehouseDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "WarehouseDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class WarehouseDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WarehouseDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodCreate",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodRead",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodUpdate",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodService/WarehouseDeliveryMethodDelete",
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__delivery__method__pb2.WarehouseDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/order_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/sales/order_line.proto\x12$pro.omni.oms.api.v1.sales.order.line\x1a\x11\x63ommon/base.proto"\x93\x02\n\tOrderLine\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08order_id\x18\x02 \x01(\x05\x12\x12\n\nproduct_id\x18\x03 \x01(\x05\x12\x10\n\x08quantity\x18\x04 \x01(\x02\x12\x0e\n\x06uom_id\x18\x05 \x01(\x05\x12\x12\n\nprice_unit\x18\x06 \x01(\x02\x12\x0e\n\x06tax_id\x18\x07 \x01(\x05\x12\x10\n\x08\x64iscount\x18\x08 \x01(\x02\x12\x16\n\x0eprice_subtotal\x18\t \x01(\x02\x12\x13\n\x0bprice_total\x18\n \x01(\x02\x12\x0e\n\x06\x61\x63tive\x18\x0b \x01(\x08\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xfb\x01\n\x16OrderLineCreateRequest\x12\x10\n\x08order_id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\x05\x12\x10\n\x08quantity\x18\x03 \x01(\x02\x12\x0e\n\x06uom_id\x18\x04 \x01(\x05\x12\x12\n\nprice_unit\x18\x05 \x01(\x02\x12\x0e\n\x06tax_id\x18\x06 \x01(\x05\x12\x10\n\x08\x64iscount\x18\x07 \x01(\x02\x12\x16\n\x0eprice_subtotal\x18\x08 \x01(\x02\x12\x13\n\x0bprice_total\x18\t \x01(\x02\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17OrderLineCreateResponse\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf2\x02\n\x14OrderLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n\x15OrderLineReadResponse\x12\x44\n\x0border_lines\x18\x01 \x03(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x95\x01\n\x16OrderLineUpdateRequest\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17OrderLineUpdateResponse\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\\\n\x16OrderLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17OrderLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd8\x04\n\x10OrderLineService\x12\x90\x01\n\x0fOrderLineCreate\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineCreateRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineCreateResponse"\x00\x12\x8a\x01\n\rOrderLineRead\x12:.pro.omni.oms.api.v1.sales.order.line.OrderLineReadRequest\x1a;.pro.omni.oms.api.v1.sales.order.line.OrderLineReadResponse"\x00\x12\x90\x01\n\x0fOrderLineUpdate\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineUpdateRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineUpdateResponse"\x00\x12\x90\x01\n\x0fOrderLineDelete\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineDeleteRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.order_line_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _ORDERLINE._serialized_start = 87
    _ORDERLINE._serialized_end = 362
    _ORDERLINECREATEREQUEST._serialized_start = 365
    _ORDERLINECREATEREQUEST._serialized_end = 616
    _ORDERLINECREATERESPONSE._serialized_start = 619
    _ORDERLINECREATERESPONSE._serialized_end = 788
    _ORDERLINEREADREQUEST._serialized_start = 791
    _ORDERLINEREADREQUEST._serialized_end = 1161
    _ORDERLINEREADRESPONSE._serialized_start = 1164
    _ORDERLINEREADRESPONSE._serialized_end = 1391
    _ORDERLINEUPDATEREQUEST._serialized_start = 1394
    _ORDERLINEUPDATEREQUEST._serialized_end = 1543
    _ORDERLINEUPDATERESPONSE._serialized_start = 1546
    _ORDERLINEUPDATERESPONSE._serialized_end = 1715
    _ORDERLINEDELETEREQUEST._serialized_start = 1717
    _ORDERLINEDELETEREQUEST._serialized_end = 1809
    _ORDERLINEDELETERESPONSE._serialized_start = 1811
    _ORDERLINEDELETERESPONSE._serialized_end = 1911
    _ORDERLINESERVICE._serialized_start = 1914
    _ORDERLINESERVICE._serialized_end = 2514
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Attachment(_message.Message):
    __slots__ = ["active", "doc_id", "id", "name", "object_audit", "type"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DOC_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    doc_id: str
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    type: str
    def __init__(
        self,
        id: _Optional[int] = ...,
        doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class AttachmentCreateRequest(_message.Message):
    __slots__ = ["context", "doc_id", "name", "type"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    DOC_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    doc_id: str
    name: str
    type: str
    def __init__(
        self,
        doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttachmentCreateResponse(_message.Message):
    __slots__ = ["attachment", "response_standard"]
    ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    attachment: Attachment
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attachment: _Optional[_Union[Attachment, _Mapping]] = ...,
    ) -> None: ...

class AttachmentDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class AttachmentDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AttachmentReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttachmentReadResponse(_message.Message):
    __slots__ = ["attachments", "meta_data", "response_standard"]
    ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    attachments: _containers.RepeatedCompositeFieldContainer[Attachment]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        attachments: _Optional[_Iterable[_Union[Attachment, _Mapping]]] = ...,
    ) -> None: ...

class AttachmentUpdateRequest(_message.Message):
    __slots__ = ["attachment", "context"]
    ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    attachment: Attachment
    context: _base_pb2.Context
    def __init__(
        self,
        attachment: _Optional[_Union[Attachment, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttachmentUpdateResponse(_message.Message):
    __slots__ = ["attachment", "response_standard"]
    ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    attachment: Attachment
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attachment: _Optional[_Union[Attachment, _Mapping]] = ...,
    ) -> None: ...

class Carrier(_message.Message):
    __slots__ = ["active", "code", "id", "name", "object_audit"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    code: str
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class CarrierCreateRequest(_message.Message):
    __slots__ = ["code", "context", "name"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    code: str
    context: _base_pb2.Context
    name: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CarrierCreateResponse(_message.Message):
    __slots__ = ["carrier", "response_standard"]
    CARRIER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    carrier: Carrier
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        carrier: _Optional[_Union[Carrier, _Mapping]] = ...,
    ) -> None: ...

class CarrierDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class CarrierDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class CarrierReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CarrierReadResponse(_message.Message):
    __slots__ = ["carriers", "meta_data", "response_standard"]
    CARRIERS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    carriers: _containers.RepeatedCompositeFieldContainer[Carrier]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        carriers: _Optional[_Iterable[_Union[Carrier, _Mapping]]] = ...,
    ) -> None: ...

class CarrierUpdateRequest(_message.Message):
    __slots__ = ["carrier", "context"]
    CARRIER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    carrier: Carrier
    context: _base_pb2.Context
    def __init__(
        self,
        carrier: _Optional[_Union[Carrier, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CarrierUpdateResponse(_message.Message):
    __slots__ = ["carrier", "response_standard"]
    CARRIER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    carrier: Carrier
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        carrier: _Optional[_Union[Carrier, _Mapping]] = ...,
    ) -> None: ...

class Picking(_message.Message):
    __slots__ = [
        "active",
        "attachment_guide_id",
        "attachment_invoice_id",
        "carrier_id",
        "carrier_tracking_ref",
        "date_delivery",
        "date_done",
        "date_start_preparation",
        "group_id",
        "id",
        "location_dest_id",
        "location_id",
        "name",
        "object_audit",
        "origin",
        "picking_type_id",
        "scheduled_date",
        "shipping_weight",
        "time_assigned",
        "time_total_preparation",
        "user_id",
        "weight",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ATTACHMENT_GUIDE_ID_FIELD_NUMBER: _ClassVar[int]
    ATTACHMENT_INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    CARRIER_ID_FIELD_NUMBER: _ClassVar[int]
    CARRIER_TRACKING_REF_FIELD_NUMBER: _ClassVar[int]
    DATE_DELIVERY_FIELD_NUMBER: _ClassVar[int]
    DATE_DONE_FIELD_NUMBER: _ClassVar[int]
    DATE_START_PREPARATION_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_DEST_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEDULED_DATE_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_ASSIGNED_FIELD_NUMBER: _ClassVar[int]
    TIME_TOTAL_PREPARATION_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    attachment_guide_id: int
    attachment_invoice_id: int
    carrier_id: int
    carrier_tracking_ref: str
    date_delivery: _timestamp_pb2.Timestamp
    date_done: _timestamp_pb2.Timestamp
    date_start_preparation: _timestamp_pb2.Timestamp
    group_id: int
    id: int
    location_dest_id: int
    location_id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    origin: str
    picking_type_id: int
    scheduled_date: _timestamp_pb2.Timestamp
    shipping_weight: float
    time_assigned: float
    time_total_preparation: float
    user_id: int
    weight: float
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        picking_type_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        location_dest_id: _Optional[int] = ...,
        user_id: _Optional[int] = ...,
        attachment_guide_id: _Optional[int] = ...,
        attachment_invoice_id: _Optional[int] = ...,
        origin: _Optional[str] = ...,
        date_start_preparation: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        date_done: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        scheduled_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        time_total_preparation: _Optional[float] = ...,
        time_assigned: _Optional[float] = ...,
        carrier_id: _Optional[int] = ...,
        date_delivery: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        carrier_tracking_ref: _Optional[str] = ...,
        group_id: _Optional[int] = ...,
        weight: _Optional[float] = ...,
        shipping_weight: _Optional[float] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class PickingCreateRequest(_message.Message):
    __slots__ = [
        "attachment_guide_id",
        "attachment_invoice_id",
        "carrier_id",
        "carrier_tracking_ref",
        "context",
        "date_delivery",
        "date_done",
        "date_start_preparation",
        "group_id",
        "location_dest_id",
        "location_id",
        "name",
        "origin",
        "picking_type_id",
        "scheduled_date",
        "shipping_weight",
        "time_assigned",
        "time_total_preparation",
        "user_id",
        "weight",
    ]
    ATTACHMENT_GUIDE_ID_FIELD_NUMBER: _ClassVar[int]
    ATTACHMENT_INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    CARRIER_ID_FIELD_NUMBER: _ClassVar[int]
    CARRIER_TRACKING_REF_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    DATE_DELIVERY_FIELD_NUMBER: _ClassVar[int]
    DATE_DONE_FIELD_NUMBER: _ClassVar[int]
    DATE_START_PREPARATION_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_DEST_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEDULED_DATE_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_ASSIGNED_FIELD_NUMBER: _ClassVar[int]
    TIME_TOTAL_PREPARATION_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    attachment_guide_id: int
    attachment_invoice_id: int
    carrier_id: int
    carrier_tracking_ref: str
    context: _base_pb2.Context
    date_delivery: _timestamp_pb2.Timestamp
    date_done: _timestamp_pb2.Timestamp
    date_start_preparation: _timestamp_pb2.Timestamp
    group_id: int
    location_dest_id: int
    location_id: int
    name: str
    origin: str
    picking_type_id: int
    scheduled_date: _timestamp_pb2.Timestamp
    shipping_weight: float
    time_assigned: float
    time_total_preparation: float
    user_id: int
    weight: float
    def __init__(
        self,
        name: _Optional[str] = ...,
        picking_type_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        location_dest_id: _Optional[int] = ...,
        user_id: _Optional[int] = ...,
        attachment_guide_id: _Optional[int] = ...,
        attachment_invoice_id: _Optional[int] = ...,
        origin: _Optional[str] = ...,
        date_start_preparation: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        date_done: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        scheduled_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        time_total_preparation: _Optional[float] = ...,
        time_assigned: _Optional[float] = ...,
        carrier_id: _Optional[int] = ...,
        date_delivery: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        carrier_tracking_ref: _Optional[str] = ...,
        group_id: _Optional[int] = ...,
        weight: _Optional[float] = ...,
        shipping_weight: _Optional[float] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingCreateResponse(_message.Message):
    __slots__ = ["picking", "response_standard"]
    PICKING_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picking: Picking
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking: _Optional[_Union[Picking, _Mapping]] = ...,
    ) -> None: ...

class PickingDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class PickingDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class PickingReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingReadResponse(_message.Message):
    __slots__ = ["meta_data", "pickings", "response_standard"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    PICKINGS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    pickings: _containers.RepeatedCompositeFieldContainer[Picking]
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        pickings: _Optional[_Iterable[_Union[Picking, _Mapping]]] = ...,
    ) -> None: ...

class PickingUpdateRequest(_message.Message):
    __slots__ = ["context", "picking"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PICKING_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    picking: Picking
    def __init__(
        self,
        picking: _Optional[_Union[Picking, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingUpdateResponse(_message.Message):
    __slots__ = ["picking", "response_standard"]
    PICKING_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picking: Picking
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking: _Optional[_Union[Picking, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroup(_message.Message):
    __slots__ = ["active", "id", "move_type", "name", "object_audit"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MOVE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    id: int
    move_type: str
    name: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        move_type: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroupCreateRequest(_message.Message):
    __slots__ = ["context", "move_type", "name"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    MOVE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    move_type: str
    name: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        move_type: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroupCreateResponse(_message.Message):
    __slots__ = ["procurement_group", "response_standard"]
    PROCUREMENT_GROUP_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    procurement_group: ProcurementGroup
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        procurement_group: _Optional[_Union[ProcurementGroup, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroupDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ProcurementGroupDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ProcurementGroupReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroupReadResponse(_message.Message):
    __slots__ = ["meta_data", "procurement_groups", "response_standard"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    PROCUREMENT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    procurement_groups: _containers.RepeatedCompositeFieldContainer[ProcurementGroup]
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        procurement_groups: _Optional[_Iterable[_Union[ProcurementGroup, _Mapping]]] = ...,
    ) -> None: ...

class ProcurementGroupUpdateRequest(_message.Message):
    __slots__ = ["context", "procurement_group"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PROCUREMENT_GROUP_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    procurement_group: ProcurementGroup
    def __init__(
        self,
        procurement_group: _Optional[_Union[ProcurementGroup, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProcurementGroupUpdateResponse(_message.Message):
    __slots__ = ["procurement_group", "response_standard"]
    PROCUREMENT_GROUP_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    procurement_group: ProcurementGroup
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        procurement_group: _Optional[_Union[ProcurementGroup, _Mapping]] = ...,
    ) -> None: ...

class User(_message.Message):
    __slots__ = ["active", "id", "name", "object_audit", "user_doc_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    USER_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    user_doc_id: str
    def __init__(
        self,
        id: _Optional[int] = ...,
        user_doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class UserCreateRequest(_message.Message):
    __slots__ = ["context", "name", "user_doc_id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    USER_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    name: str
    user_doc_id: str
    def __init__(
        self,
        user_doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserCreateResponse(_message.Message):
    __slots__ = ["response_standard", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...

class UserDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class UserDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class UserReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "users"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...,
    ) -> None: ...

class UserUpdateRequest(_message.Message):
    __slots__ = ["context", "user"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    user: User
    def __init__(
        self,
        user: _Optional[_Union[User, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/sales/delivery_method.proto\x12)pro.omni.oms.api.v1.sales.delivery.method\x1a\x11\x63ommon/base.proto"\x89\x01\n\x0e\x44\x65liveryMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"q\n\x1b\x44\x65liveryMethodCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodCreateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf7\x02\n\x19\x44\x65liveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x1a\x44\x65liveryMethodReadResponse\x12S\n\x10\x64\x65livery_methods\x18\x01 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa9\x01\n\x1b\x44\x65liveryMethodUpdateRequest\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodUpdateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"a\n\x1b\x44\x65liveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"i\n\x1c\x44\x65liveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc5\x05\n\x15\x44\x65liveryMethodService\x12\xaa\x01\n\x15\x44\x65liveryServiceCreate\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodCreateRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodCreateResponse"\x00\x12\xa4\x01\n\x13\x44\x65liveryServiceRead\x12\x44.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodReadRequest\x1a\x45.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodReadResponse"\x00\x12\xaa\x01\n\x15\x44\x65liveryServiceUpdate\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodUpdateRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodUpdateResponse"\x00\x12\xaa\x01\n\x15\x44\x65liveryServiceDelete\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodDeleteRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.delivery_method_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _DELIVERYMETHOD._serialized_start = 97
    _DELIVERYMETHOD._serialized_end = 234
    _DELIVERYMETHODCREATEREQUEST._serialized_start = 236
    _DELIVERYMETHODCREATEREQUEST._serialized_end = 349
    _DELIVERYMETHODCREATERESPONSE._serialized_start = 352
    _DELIVERYMETHODCREATERESPONSE._serialized_end = 541
    _DELIVERYMETHODREADREQUEST._serialized_start = 544
    _DELIVERYMETHODREADREQUEST._serialized_end = 919
    _DELIVERYMETHODREADRESPONSE._serialized_start = 922
    _DELIVERYMETHODREADRESPONSE._serialized_end = 1169
    _DELIVERYMETHODUPDATEREQUEST._serialized_start = 1172
    _DELIVERYMETHODUPDATEREQUEST._serialized_end = 1341
    _DELIVERYMETHODUPDATERESPONSE._serialized_start = 1344
    _DELIVERYMETHODUPDATERESPONSE._serialized_end = 1533
    _DELIVERYMETHODDELETEREQUEST._serialized_start = 1535
    _DELIVERYMETHODDELETEREQUEST._serialized_end = 1632
    _DELIVERYMETHODDELETERESPONSE._serialized_start = 1634
    _DELIVERYMETHODDELETERESPONSE._serialized_end = 1739
    _DELIVERYMETHODSERVICE._serialized_start = 1742
    _DELIVERYMETHODSERVICE._serialized_end = 2451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/location.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/location.proto\x12"pro.omni.oms.api.v1.rules.location\x1a\x11\x63ommon/base.proto"\x83\x01\n\x08Location\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"]\n\x15LocationCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16LocationCreateResponse\x12>\n\x08Location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13LocationReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x14LocationReadResponse\x12?\n\tLocations\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15LocationUpdateRequest\x12>\n\x08Location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16LocationUpdateResponse\x12>\n\x08Location\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15LocationDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16LocationDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0fLocationService\x12\x89\x01\n\x0eLocationCreate\x12\x39.pro.omni.oms.api.v1.rules.location.LocationCreateRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationCreateResponse"\x00\x12\x83\x01\n\x0cLocationRead\x12\x37.pro.omni.oms.api.v1.rules.location.LocationReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.location.LocationReadResponse"\x00\x12\x89\x01\n\x0eLocationUpdate\x12\x39.pro.omni.oms.api.v1.rules.location.LocationUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationUpdateResponse"\x00\x12\x89\x01\n\x0eLocationDelete\x12\x39.pro.omni.oms.api.v1.rules.location.LocationDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.location.LocationDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.location_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _LOCATION._serialized_start = 83
    _LOCATION._serialized_end = 214
    _LOCATIONCREATEREQUEST._serialized_start = 216
    _LOCATIONCREATEREQUEST._serialized_end = 309
    _LOCATIONCREATERESPONSE._serialized_start = 312
    _LOCATIONCREATERESPONSE._serialized_end = 475
    _LOCATIONREADREQUEST._serialized_start = 478
    _LOCATIONREADREQUEST._serialized_end = 847
    _LOCATIONREADRESPONSE._serialized_start = 850
    _LOCATIONREADRESPONSE._serialized_end = 1071
    _LOCATIONUPDATEREQUEST._serialized_start = 1074
    _LOCATIONUPDATEREQUEST._serialized_end = 1217
    _LOCATIONUPDATERESPONSE._serialized_start = 1220
    _LOCATIONUPDATERESPONSE._serialized_end = 1383
    _LOCATIONDELETEREQUEST._serialized_start = 1385
    _LOCATIONDELETEREQUEST._serialized_end = 1476
    _LOCATIONDELETERESPONSE._serialized_start = 1478
    _LOCATIONDELETERESPONSE._serialized_end = 1577
    _LOCATIONSERVICE._serialized_start = 1580
    _LOCATIONSERVICE._serialized_end = 2151
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import picking_pb2 as v1_dot_stock_dot_picking__pb2


class PickingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PickingCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
        )
        self.PickingRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
        )
        self.PickingUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
        )
        self.PickingDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
        )
        self.UserCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserCreateResponse.FromString,
        )
        self.UserRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserReadResponse.FromString,
        )
        self.UserUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserUpdateResponse.FromString,
        )
        self.UserDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.UserDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.UserDeleteResponse.FromString,
        )
        self.AttachmentCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.FromString,
        )
        self.AttachmentRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.FromString,
        )
        self.AttachmentUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.FromString,
        )
        self.AttachmentDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.FromString,
        )
        self.CarrierCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.FromString,
        )
        self.CarrierRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierReadResponse.FromString,
        )
        self.CarrierUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.FromString,
        )
        self.CarrierDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.FromString,
        )
        self.ProcurementGroupCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupCreate",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.FromString,
        )
        self.ProcurementGroupRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupRead",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.FromString,
        )
        self.ProcurementGroupUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupUpdate",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.FromString,
        )
        self.ProcurementGroupDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupDelete",
            request_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.FromString,
        )


class PickingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PickingCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcurementGroupDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PickingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PickingCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingCreateResponse.SerializeToString,
        ),
        "PickingRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingReadResponse.SerializeToString,
        ),
        "PickingUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.SerializeToString,
        ),
        "PickingDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.SerializeToString,
        ),
        "UserCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UserCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserCreateResponse.SerializeToString,
        ),
        "UserRead": grpc.unary_unary_rpc_method_handler(
            servicer.UserRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserReadResponse.SerializeToString,
        ),
        "UserUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UserUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserUpdateResponse.SerializeToString,
        ),
        "UserDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UserDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.UserDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.UserDeleteResponse.SerializeToString,
        ),
        "AttachmentCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.SerializeToString,
        ),
        "AttachmentRead": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.SerializeToString,
        ),
        "AttachmentUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.SerializeToString,
        ),
        "AttachmentDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.SerializeToString,
        ),
        "CarrierCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.SerializeToString,
        ),
        "CarrierRead": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierReadResponse.SerializeToString,
        ),
        "CarrierUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.SerializeToString,
        ),
        "CarrierDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.SerializeToString,
        ),
        "ProcurementGroupCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupCreate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.SerializeToString,
        ),
        "ProcurementGroupRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupRead,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.SerializeToString,
        ),
        "ProcurementGroupUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupUpdate,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.SerializeToString,
        ),
        "ProcurementGroupDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProcurementGroupDelete,
            request_deserializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.picking.PickingService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PickingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PickingCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingCreate",
            v1_dot_stock_dot_picking__pb2.PickingCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingRead",
            v1_dot_stock_dot_picking__pb2.PickingReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingUpdate",
            v1_dot_stock_dot_picking__pb2.PickingUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/PickingDelete",
            v1_dot_stock_dot_picking__pb2.PickingDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.PickingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserCreate",
            v1_dot_stock_dot_picking__pb2.UserCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserRead",
            v1_dot_stock_dot_picking__pb2.UserReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserUpdate",
            v1_dot_stock_dot_picking__pb2.UserUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/UserDelete",
            v1_dot_stock_dot_picking__pb2.UserDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.UserDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentCreate",
            v1_dot_stock_dot_picking__pb2.AttachmentCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentRead",
            v1_dot_stock_dot_picking__pb2.AttachmentReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentUpdate",
            v1_dot_stock_dot_picking__pb2.AttachmentUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/AttachmentDelete",
            v1_dot_stock_dot_picking__pb2.AttachmentDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.AttachmentDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierCreate",
            v1_dot_stock_dot_picking__pb2.CarrierCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierRead",
            v1_dot_stock_dot_picking__pb2.CarrierReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierUpdate",
            v1_dot_stock_dot_picking__pb2.CarrierUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/CarrierDelete",
            v1_dot_stock_dot_picking__pb2.CarrierDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.CarrierDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupCreate",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupRead",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupUpdate",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProcurementGroupDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking.PickingService/ProcurementGroupDelete",
            v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__pb2.ProcurementGroupDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
